## Petra-M(RFP)

This module provides additional module for waves in plasmas

### EM3D : Frequency domain Maxwell equation in 3D
  Domain:   
 *    EM3D_ColdPlasma  : Cold magnetised plasma
 *    EM3D_LkPlasma    : local-K approx. plasma
 
### EM2Da : Frequency domain Maxwell equation in 2D axissymetric space
  Domain:   
 *    EM2Da_ColdPlasma  : Cold magnetised plasma
 *    EM2Da_LkPlasma    : local-K approx. plasma

### EM2D : Frequency domain Maxwell equation in 2D space
  Domain:   
 *    EM2D_ColdPlasma  : Cold magnetised plasma
 *    EM2D_LkPlasma    : local-K approx. plasma

### EM1D : Frequency domain Maxwell equation in 1D
  Domain:   
 *    EM1D_ColdPlasma  : Cold magnetised plasma
 *    EM1D_LkPlasma    : local-K approx. plasma 
 

